@@ -21,7 +21,7 @@ __version__ = config.VERSION
 logging.basicConfig(format=settings.LOG_FORMAT, level=getattr(logging, settings.LOG_LEVEL))
 LOGGER = logging.getLogger(__name__)
 
-if settings.SENTRY_DSN:
+if settings.SENTRY_ENABLED:
     sentry_sdk.init(settings.SENTRY_DSN, release='satnogs-client@{}'.format(__version__))
     with sentry_sdk.configure_scope() as scope:
         scope.user = {'id': settings.SATNOGS_STATION_ID}
@@ -37,7 +37,7 @@ def main():
         sys.exit(-1)
 
     LOGGER.info('Starting status listener thread...')
-    gps_locator = locator.Locator(120)
+    gps_locator = locator.Locator()
     gps_locator.update_location()
     status_listener()
     LOGGER.info('Press Ctrl+C to exit SatNOGS poller')
