@@ -18,7 +18,7 @@ from satnogsclient import settings
 from satnogsclient.artifacts import Artifacts
 from satnogsclient.observer.worker import WorkerFreq, WorkerTrack
 from satnogsclient.scheduler import SCHEDULER
-from satnogsclient.waterfall import Waterfall
+from satnogsclient.waterfall import EmptyArrayError, Waterfall
 
 try:
     from urllib.parse import urljoin
@@ -212,6 +212,8 @@ class Observer(object):
                 self.remove_waterfall_file()
         except FileNotFoundError:
             LOGGER.error('No waterfall data file found')
+        except EmptyArrayError:
+            LOGGER.error('Waterfall data array is empty')
 
         # PUT client version and metadata
         base_url = urljoin(settings.SATNOGS_NETWORK_API_URL, 'observations/')
@@ -246,15 +248,23 @@ class Observer(object):
             LOGGER.error('%s: Unexpected error: %s', url, err)
 
         if settings.ARTIFACTS_ENABLED:
-            artifact = Artifacts(waterfall, self.observation_id)
+            metadata = {
+                'observation_id': self.observation_id,
+                'frequency': str(self.frequency),
+                'tle': '{}\n{}\n{}\n'.format(self.tle['tle0'], self.tle['tle1'], self.tle['tle2']),
+                'location': {
+                    'latitude': self.location['lat'],
+                    'longitude': self.location['lon'],
+                    'altitude': self.location['elev']
+                }
+            }
+            artifact = Artifacts(waterfall, metadata)
             artifact.create()
             SCHEDULER.add_job(post_artifacts,
                               args=(artifact.artifacts_file, str(self.observation_id)))
 
     def run_rot(self):
-        self.tracker_rot = WorkerTrack(ip=None,
-                                       port=self.rot_port,
-                                       frequency=self.frequency,
+        self.tracker_rot = WorkerTrack(port=self.rot_port,
                                        time_to_stop=self.observation_end,
                                        sleep_time=3)
         LOGGER.debug('TLE: %s', self.tle)
@@ -265,11 +275,10 @@ class Observer(object):
     def run_rig(self):
         self.tracker_freq = WorkerFreq(ip=self.rig_ip,
                                        port=self.rig_port,
-                                       frequency=self.frequency,
                                        time_to_stop=self.observation_end)
         LOGGER.debug('Rig Frequency %s', self.frequency)
         LOGGER.debug('Observation end: %s', self.observation_end)
-        self.tracker_freq.trackobject(self.location, self.tle)
+        self.tracker_freq.trackobject(self.frequency, self.location, self.tle)
         self.tracker_freq.trackstart()
 
     def poll_gnu_proc_status(self, flowgraph):
